@@ -204,7 +204,7 @@ void LatexCodeGenerator::writeCodeLink(CodeSymbolType,
   size_t l = name.length();
   if (ref.isEmpty() && usePDFLatex && pdfHyperlinks)
   {
-    *m_t << "\\mbox{\\hyperlink{";
+    *m_t << "\\doxymbox{\\hyperlink{";
     if (!f.isEmpty()) *m_t << stripPath(f);
     if (!f.isEmpty() && !anchor.isEmpty()) *m_t << "_";
     if (!anchor.isEmpty()) *m_t << anchor;
@@ -308,7 +308,10 @@ void LatexCodeGenerator::startCodeFragment(const QCString &style)
 void LatexCodeGenerator::endCodeFragment(const QCString &style)
 {
   //endCodeLine checks is there is still an open code line, if so closes it.
+  bool wasHidden = m_hide;
+  m_hide = false;
   endCodeLine();
+  m_hide = wasHidden;
 
   *m_t << "\\end{" << style << "}\n";
 }
@@ -703,7 +706,7 @@ void LatexGenerator::writeStyleSheetFile(TextStream &t)
   writeDefaultStyleSheet(t);
 }
 
-void LatexGenerator::startFile(const QCString &name,const QCString &,const QCString &,int,int hierarchyLevel)
+void LatexGenerator::startFile(const QCString &name,bool,const QCString &,const QCString &,int,int hierarchyLevel)
 {
 #if 0
   setEncoding(Config_getString(LATEX_OUTPUT_ENCODING));
@@ -745,14 +748,15 @@ static QCString extraLatexStyleSheet()
       if (fi.exists())
       {
         result += "\\usepackage{";
-        if (checkExtension(fi.fileName().c_str(), LATEX_STYLE_EXTENSION))
+        QCString fn = fi.fileName();
+        if (checkExtension(fn, LATEX_STYLE_EXTENSION))
         {
           // strip the extension, it will be added by the usepackage in the tex conversion process
-          result += stripExtensionGeneral(fi.fileName().c_str(), LATEX_STYLE_EXTENSION);
+          result += stripExtensionGeneral(fn, LATEX_STYLE_EXTENSION);
         }
         else
         {
-          result += fi.fileName();
+          result += fn;
         }
         result += "}\n";
       }
@@ -871,6 +875,10 @@ static QCString substituteLatexKeywords(const QCString &file,
   result = substituteKeywords(file,result,
   {
     // keyword                     value getter
+    { "$datetime",                 [&]() { return dateToString(DateTimeType::DateTime);         } },
+    { "$date",                     [&]() { return dateToString(DateTimeType::Date);             } },
+    { "$time",                     [&]() { return dateToString(DateTimeType::Time);             } },
+    { "$year",                     [&]() { return yearToString();                               } },
     { "$latexdocumentpre",         [&]() { return theTranslator->latexDocumentPre();            } },
     { "$latexdocumentpost",        [&]() { return theTranslator->latexDocumentPost();           } },
     { "$generatedby",              [&]() { return generatedBy;                                  } },
@@ -1290,14 +1298,6 @@ void LatexGenerator::writeStyleInfo(int part)
   writeDefaultStyleSheet(m_t);
   endPlainFile();
 
-  // workaround for the problem caused by change in LaTeX in version 2019
-  // in the unmaintained tabu package
-  startPlainFile("tabu_doxygen.sty");
-  m_t << ResourceMgr::instance().getAsString("tabu_doxygen.sty");
-  endPlainFile();
-  startPlainFile("longtable_doxygen.sty");
-  m_t << ResourceMgr::instance().getAsString("longtable_doxygen.sty");
-  endPlainFile();
   /// an extension of the etoc package is required that is only available in the
   /// newer version. Providing the updated version to be used with older versions
   /// of LaTeX
@@ -1381,7 +1381,7 @@ void LatexGenerator::startTextLink(const QCString &f,const QCString &anchor)
   bool pdfHyperlinks = Config_getBool(PDF_HYPERLINKS);
   if (!m_disableLinks && pdfHyperlinks)
   {
-    m_t << "\\mbox{\\hyperlink{";
+    m_t << "\\doxymbox{\\hyperlink{";
     if (!f.isEmpty()) m_t << stripPath(f);
     if (!anchor.isEmpty()) m_t << "_" << anchor;
     m_t << "}{";
@@ -1410,7 +1410,7 @@ static QCString objectLinkToString(const QCString &ref, const QCString &f,
   QCString result;
   if (!disableLinks && ref.isEmpty() && pdfHyperlinks)
   {
-    result += "\\mbox{\\hyperlink{";
+    result += "\\doxymbox{\\hyperlink{";
     if (!f.isEmpty()) result += stripPath(f);
     if (!f.isEmpty() && !anchor.isEmpty()) result += "_";
     if (!anchor.isEmpty()) result += anchor;
@@ -1492,23 +1492,7 @@ void LatexGenerator::endTitleHead(const QCString &fileName,const QCString &name)
   }
   if (!name.isEmpty())
   {
-    m_t << "\\index{";
-    m_t << latexEscapeLabelName(name);
-    m_t << "@{";
-    m_t << latexEscapeIndexChars(name);
-    m_t << "}}\n";
-  }
-}
-
-void LatexGenerator::startTitle()
-{
-  if (Config_getBool(COMPACT_LATEX))
-  {
-    m_t << "\\doxysubsection{";
-  }
-  else
-  {
-    m_t << "\\doxysection{";
+    latexWriteIndexItem(m_t,name);
   }
 }
 
@@ -1569,33 +1553,8 @@ void LatexGenerator::startMemberDoc(const QCString &clname,
 {
   if (!memname.isEmpty() && memname[0]!='@')
   {
-    m_t << "\\index{";
-    if (!clname.isEmpty())
-    {
-      m_t << latexEscapeLabelName(clname);
-      m_t << "@{";
-      m_t << latexEscapeIndexChars(clname);
-      m_t << "}!";
-    }
-    m_t << latexEscapeLabelName(memname);
-    m_t << "@{";
-    m_t << latexEscapeIndexChars(memname);
-    m_t << "}}\n";
-
-    m_t << "\\index{";
-    m_t << latexEscapeLabelName(memname);
-    m_t << "@{";
-    m_t << latexEscapeIndexChars(memname);
-    m_t << "}";
-    if (!clname.isEmpty())
-    {
-      m_t << "!";
-      m_t << latexEscapeLabelName(clname);
-      m_t << "@{";
-      m_t << latexEscapeIndexChars(clname);
-      m_t << "}";
-    }
-    m_t << "}\n";
+    latexWriteIndexItem(m_t,clname,memname);
+    latexWriteIndexItem(m_t,memname,clname);
   }
   bool compactLatex = Config_getBool(COMPACT_LATEX);
   bool pdfHyperlinks = Config_getBool(PDF_HYPERLINKS);
@@ -1644,7 +1603,7 @@ void LatexGenerator::startDoxyAnchor(const QCString &fName,const QCString &,
 {
   bool pdfHyperlinks = Config_getBool(PDF_HYPERLINKS);
   bool usePDFLatex   = Config_getBool(USE_PDFLATEX);
-  if (m_insideTableEnv) m_t << "\\mbox{"; // see issue #6093
+  if (m_insideTableEnv) m_t << "\\doxymbox{"; // see issue #6093
   if (usePDFLatex && pdfHyperlinks)
   {
     m_t << "\\Hypertarget{";
@@ -1696,20 +1655,7 @@ void LatexGenerator::addIndexItem(const QCString &s1,const QCString &s2)
 {
   if (!s1.isEmpty())
   {
-    m_t << "\\index{";
-    m_t << latexEscapeLabelName(s1);
-    m_t << "@{";
-    m_t << latexEscapeIndexChars(s1);
-    m_t << "}";
-    if (!s2.isEmpty())
-    {
-      m_t << "!";
-      m_t << latexEscapeLabelName(s2);
-      m_t << "@{";
-      m_t << latexEscapeIndexChars(s2);
-      m_t << "}";
-    }
-    m_t << "}";
+    latexWriteIndexItem(m_t,s1,s2);
   }
 }
 
@@ -2138,7 +2084,7 @@ void LatexGenerator::exceptionEntry(const QCString &prefix,bool closeBracket)
   m_t << " ";
 }
 
-void LatexGenerator::writeDoc(const IDocNodeAST *ast,const Definition *ctx,const MemberDef *,int)
+void LatexGenerator::writeDoc(const IDocNodeAST *ast,const Definition *ctx,const MemberDef *,int,int)
 {
   const DocNodeAST *astImpl = dynamic_cast<const DocNodeAST*>(ast);
   if (astImpl)
@@ -2322,6 +2268,16 @@ void LatexGenerator::startLocalToc(int level)
   m_t << "\\localtableofcontents\n";
 }
 
+void LatexGenerator::startEmbeddedDoc(int indent)
+{
+  m_t << "\\begin{DoxyEmbeddedDoc}[" << indent << "]\n";
+}
+
+void LatexGenerator::endEmbeddedDoc()
+{
+  m_t << "\\end{DoxyEmbeddedDoc}\n";
+}
+
 //--------------------------------------------------------------------------------------------------
 
 void writeExtraLatexPackages(TextStream &t)
@@ -2334,9 +2290,9 @@ void writeExtraLatexPackages(TextStream &t)
     for (const auto &pkgName : extraPackages)
     {
       if ((pkgName[0] == '[') || (pkgName[0] == '{'))
-        t << "\\usepackage" << pkgName.c_str() << "\n";
+        t << "\\usepackage" << pkgName << "\n";
       else
-        t << "\\usepackage{" << pkgName.c_str() << "}\n";
+        t << "\\usepackage{" << pkgName << "}\n";
     }
     t << "\n";
   }
@@ -2449,7 +2405,7 @@ void filterLatexString(TextStream &t,const QCString &str,
           else
             t << static_cast<char>(c);
           break;
-        case '#':  t << "\\#";           break;
+        case '#':  t << "\\+\\#";        break;
         case '$':  t << "\\$";           break;
         case '%':  t << "\\%";           break;
         case '^':  processEntity(t,pdfHyperlinks,"$^\\wedge$","\\string^");    break;
@@ -2496,13 +2452,13 @@ void filterLatexString(TextStream &t,const QCString &str,
         case '|':  processEntity(t,pdfHyperlinks,"$\\vert$","|");    break;
         case '~':  processEntity(t,pdfHyperlinks,"$\\sim$","\\string~");    break;
         case '[':  if (Config_getBool(PDF_HYPERLINKS) || insideItem)
-                     t << "\\mbox{[}";
+                     t << "\\+[";
                    else
                      t << "[";
                    break;
         case ']':  if (pc=='[') t << "$\\,$";
                      if (Config_getBool(PDF_HYPERLINKS) || insideItem)
-                       t << "\\mbox{]}";
+                       t << "]\\+";
                      else
                        t << "]";
                    break;
@@ -2516,7 +2472,15 @@ void filterLatexString(TextStream &t,const QCString &str,
                    break;
         case '\'': t << "\\textquotesingle{}";
                    break;
-        case '\n':  if (retainNewline) t << "\\newline"; else t << ' ';
+        case '\n': if (retainNewline)
+                   {
+                     t << "\\newline";
+                     if (insideTable) t << " ";
+                   }
+                   else
+                   {
+                     t << ' ';
+                   }
                    break;
         case ' ':  if (keepSpaces) { if (insideTabbing) t << "\\>"; else t << '~'; } else t << ' ';
                    break;
@@ -2524,7 +2488,7 @@ void filterLatexString(TextStream &t,const QCString &str,
         default:
                    //if (!insideTabbing && forceBreaks && c!=' ' && *p!=' ')
                    if (!insideTabbing &&
-                       ((c>='A' && c<='Z' && pc!=' ' && !(pc>='A' && pc <= 'Z') && pc!='\0' && *p) || (c==':' && pc!=':') || (pc=='.' && isId(c)))
+                       ((c>='A' && c<='Z' && pc!=' ' && !(pc>='A' && pc <= 'Z') && pc!='\0' && *p) || (pc=='.' && isId(c)))
                       )
                    {
                      t << "\\+";
@@ -2537,6 +2501,10 @@ void filterLatexString(TextStream &t,const QCString &str,
                    {
                      t << static_cast<char>(c);
                    }
+                   if (!insideTabbing && ((c==':' && *p!=':') || c=='/'))
+                   {
+                     t << "\\+";
+                   }
       }
     }
     pc = c;
@@ -2683,6 +2651,7 @@ QCString latexFilterURL(const QCString &s)
       case '#':  t << "\\#"; break;
       case '%':  t << "\\%"; break;
       case '\\':  t << "\\\\"; break;
+      case '\n':  break; // ignore
       default:
         if (c<0)
         {
@@ -2699,4 +2668,25 @@ QCString latexFilterURL(const QCString &s)
   return t.str();
 }
 
+void latexWriteIndexItem(TextStream &m_t,const QCString &s1,const QCString &s2)
+{
+  if (!s1.isEmpty())
+  {
+    m_t << "\\index{";
+    m_t << latexEscapeLabelName(s1);
+    m_t << "@{";
+    m_t << latexEscapeIndexChars(s1);
+    m_t << "}";
+    if (!s2.isEmpty())
+    {
+      m_t << "!";
+      m_t << latexEscapeLabelName(s2);
+      m_t << "@{";
+      m_t << latexEscapeIndexChars(s2);
+      m_t << "}";
+    }
+    m_t << "}\n";
+  }
+}
+
 
